@@ -21,6 +21,8 @@
 
 #include "config.h"
 
+#include <sys/param.h>
+
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
@@ -32,7 +34,6 @@
 #include "gvc-channel-bar.h"
 
 #define SCALE_SIZE 128
-#define GVC_CHANNEL_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GVC_TYPE_CHANNEL_BAR, GvcChannelBarPrivate))
 
 struct _GvcChannelBarPrivate
 {
@@ -45,7 +46,6 @@ struct _GvcChannelBarPrivate
         GtkWidget                  *low_image;
         GtkWidget                  *scale;
         GtkWidget                  *high_image;
-        GtkWidget                  *mute_box;
         GtkWidget                  *mute_button;
         GtkAdjustment              *adjustment;
         gboolean                    show_icons;
@@ -76,9 +76,6 @@ enum {
 
 static GParamSpec *properties[N_PROPERTIES] = { NULL, };
 
-static void     gvc_channel_bar_class_init    (GvcChannelBarClass *klass);
-static void     gvc_channel_bar_init          (GvcChannelBar      *bar);
-
 static gboolean on_scale_button_press_event   (GtkWidget          *widget,
                                                GdkEventButton     *event,
                                                GvcChannelBar      *bar);
@@ -89,7 +86,7 @@ static gboolean on_scale_scroll_event         (GtkWidget          *widget,
                                                GdkEventScroll     *event,
                                                GvcChannelBar      *bar);
 
-G_DEFINE_TYPE (GvcChannelBar, gvc_channel_bar, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (GvcChannelBar, gvc_channel_bar, GTK_TYPE_BOX)
 
 static void
 create_scale_box (GvcChannelBar *bar)
@@ -753,13 +750,41 @@ gvc_channel_bar_set_icon_name (GvcChannelBar *bar, const gchar *name)
 {
         g_return_if_fail (GVC_IS_CHANNEL_BAR (bar));
 
-        gtk_image_set_from_icon_name (GTK_IMAGE (bar->priv->image),
-                                      name,
-                                      GTK_ICON_SIZE_DIALOG);
-        if (name != NULL)
-                gtk_widget_show (bar->priv->image);
-        else
+        if (name != NULL) {
+                GtkIconTheme *icon_theme;
+                GdkPixbuf *pixbuf;
+                gint width, height;
+                GError *error = NULL;
+
+                gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &width, &height);
+                icon_theme = gtk_icon_theme_get_default ();
+                pixbuf = gtk_icon_theme_load_icon (icon_theme,
+                                                   name,
+                                                   width,
+                                                   GTK_ICON_LOOKUP_GENERIC_FALLBACK | GTK_ICON_LOOKUP_FORCE_SIZE,
+                                                   &error);
+                if (error != NULL) {
+                        g_warning ("Couldn’t load icon: %s\n", error->message);
+                        g_clear_error (&error);
+                }
+
+                if (pixbuf == NULL) {
+                        pixbuf = gdk_pixbuf_new_from_file_at_scale (name, width, height, TRUE, &error);
+                        if (error != NULL)
+                        {
+                                g_warning ("Couldn’t load icon: %s\n", error->message);
+                                g_clear_error (&error);
+                        }
+                }
+
+                if (pixbuf) {
+                        gtk_image_set_from_pixbuf (GTK_IMAGE (bar->priv->image), pixbuf);
+                        gtk_widget_show (bar->priv->image);
+                        g_object_unref (pixbuf);
+                }
+        } else {
                 gtk_widget_hide (bar->priv->image);
+        }
 
         g_object_notify_by_pspec (G_OBJECT (bar), properties[PROP_ICON_NAME]);
 }
@@ -817,6 +842,7 @@ gvc_channel_bar_scroll (GvcChannelBar *bar, GdkScrollDirection direction)
         gdouble minimum;
         gdouble maximum;
         gdouble scrollstep;
+        GSettings *settings;
 
         g_return_val_if_fail (GVC_IS_CHANNEL_BAR (bar), FALSE);
 
@@ -843,18 +869,23 @@ gvc_channel_bar_scroll (GvcChannelBar *bar, GdkScrollDirection direction)
         minimum = gtk_adjustment_get_lower (bar->priv->adjustment);
         maximum = gtk_adjustment_get_upper (bar->priv->adjustment);
 
-        scrollstep = maximum / 100.0 * 5.0;
+        /* Use the same setting for `scrollstep` as used by the media keys plugin */
+        settings = g_settings_new ("org.mate.SettingsDaemon.plugins.media-keys");
+        scrollstep = g_settings_get_int (settings, "volume-step");
+        if (scrollstep <= 0 || scrollstep > 100) {
+                GVariant *variant = g_settings_get_default_value (settings, "volume-step");
+                scrollstep = g_variant_get_int32 (variant);
+                g_variant_unref (variant);
+        }
+        g_object_unref (settings);
+
+        /* Scale the volume step size accordingly to the range used by the control */
+        scrollstep = (maximum - minimum) * scrollstep / 100;
 
         if (direction == GDK_SCROLL_UP) {
-                if (value + scrollstep > maximum)
-                        value = maximum;
-                else
-                        value = value + scrollstep;
+                value = MIN (value + scrollstep, maximum);
         } else if (direction == GDK_SCROLL_DOWN) {
-                if (value - scrollstep < minimum)
-                        value = minimum;
-                else
-                        value = value - scrollstep;
+                value = MAX (value - scrollstep, minimum);
         }
 
         gtk_adjustment_set_value (bar->priv->adjustment, value);
@@ -1063,8 +1094,6 @@ gvc_channel_bar_class_init (GvcChannelBarClass *klass)
                                      G_PARAM_STATIC_STRINGS);
 
         g_object_class_install_properties (object_class, N_PROPERTIES, properties);
-
-        g_type_class_add_private (klass, sizeof (GvcChannelBarPrivate));
 }
 
 static void
@@ -1072,7 +1101,7 @@ gvc_channel_bar_init (GvcChannelBar *bar)
 {
         GtkWidget *frame;
 
-        bar->priv = GVC_CHANNEL_BAR_GET_PRIVATE (bar);
+        bar->priv = gvc_channel_bar_get_instance_private (bar);
 
         /* Mute button */
         bar->priv->mute_button = gtk_check_button_new_with_label (_("Mute"));
